Method: Azure::NetApp::Mgmt::V2020_07_01::Models::CheckAvailabilityResponse#message

Defined in:
lib/2020-07-01/generated/azure_mgmt_netapp/models/check_availability_response.rb

#messageString

why the given name is invalid, and provide the resource naming requirements so that the user can select a valid name. If reason == AlreadyExists, explain that resource name is already in use, and direct them to select a different name.

Returns:

  • (String)

    If reason == invalid, provide the user with the reason



32
33
34
# File 'lib/2020-07-01/generated/azure_mgmt_netapp/models/check_availability_response.rb', line 32

def message
  @message
end